"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Interpreter = void 0;
const tslib_1 = require("tslib");
const compiler_1 = require("./compiler");
const fs_1 = tslib_1.__importDefault(require("fs"));
class Interpreter {
    functions;
    compiler;
    routes;
    app;
    db;
    reverseReading;
    constructor(app, routes, db, reverseReading) {
        this.compiler = new compiler_1.Compiler("");
        this.reverseReading = reverseReading;
        this.routes = routes;
        this.functions = [];
        this.app = app;
        this.db = db;
        this.load();
        this.compiler.set_functions(this.functions.map(function (fn) {
            return fn.data.name;
        }));
    }
    async resolve_fields(data) {
        if (!data)
            return;
        for (let i = 0; i < data.func?.fields?.length; i++) {
            data.func = (await this.resolve_field(data, i));
        }
        ;
        return data;
    }
    ;
    async resolve_field(data, index) {
        if (data.func?.fields?.[index]) {
            for (const over of data.func.fields[index].overs) {
                let finded = data.interpreter.functions.find(f => f.data.name == over.name);
                if (finded) {
                    over.resolve_fields = this.resolve_fields;
                    over.resolve_field = this.resolve_field;
                    let new_data = { ...data, func: over, code: data.func.fields[index].value };
                    const reject = await finded.code(new_data);
                    if (reject?.code && data.func?.inside && data.func.fields) {
                        data.func.fields[index].value = reject.code;
                        data.func.inside = data.func.fields.map((field) => field.value).join(";");
                        data.func.total = `${data.func.name}[${data.func.inside}]`;
                        data.break = new_data.break;
                        data._ = new_data._;
                    }
                    ;
                }
                ;
            }
            ;
        }
        ;
        return data.func;
    }
    async parse(text, req, res, d) {
        if (text) {
            this.compiler.set_code(text);
            this.compiler.match();
            let data = {
                code: this.compiler.result || "",
                compiler: this.compiler,
                routes: this.routes,
                interpreter: this,
                app: this.app,
                _: d?._ || {},
                break: d?.break || false,
                func: null,
                req, res
            };
            let entries = Object.entries(this.compiler.matched);
            for (const fn of this.reverseReading ? entries : entries.reverse()) {
                if (data.break)
                    break;
                await this.run_function(fn[1], data);
            }
            ;
            return data;
        }
        ;
    }
    ;
    async run_function(fn, d) {
        let finded = this.functions.find(i => i.data.name == fn.name);
        if (finded) {
            fn.resolve_fields = this.resolve_fields;
            fn.resolve_field = this.resolve_field;
            d.func = fn;
            const reject = await finded.code(d);
            if (reject?.code) {
                d.code = reject.code?.trim() || "";
            }
            ;
        }
        ;
    }
    ;
    addFunction(func) {
        this.functions[this.functions.length] = func;
        this.compiler.functions.push(func.data.name);
        this.compiler.set_functions(this.compiler.functions);
    }
    getFunction(func) {
        let f = this.functions.find(i => i.data.name == func.name);
        if (!f)
            return null;
        return Object.assign({ name: f.data.name }, f.data.extra);
    }
    load() {
        let dirs = fs_1.default.readdirSync(__dirname.replace('classes', 'functions'));
        for (const file of dirs) {
            const r = require(`../functions/${file}`).data;
            if (r)
                this.addFunction(r);
        }
        String.prototype.replaceLast = function name(p, r) {
            const match = typeof p === 'string'
                ? p : (this.match(new RegExp(p.source, 'g')) || []).slice(-1)[0];
            if (!match)
                return this;
            const last = this.lastIndexOf(match);
            return last !== -1 ? `${this.slice(0, last)}${r}${this.slice(last + match.length)}` : this;
        };
        String.prototype.resolve = function (w, r) {
            let p_s = this.split(w);
            let last = p_s.pop();
            return p_s.join(w) + r + last;
        };
        String.prototype.unescape = function () {
            return this
                .replaceAll('@at', '@')
                .replaceAll('@left', ']')
                .replaceAll('@right', '[')
                .replaceAll('@semi', ';')
                .replaceAll('@colon', ':')
                .replaceAll('@equal', '=')
                .replaceAll('@or', '||')
                .replaceAll('@and', '&&')
                .replaceAll('@higher', '>')
                .replaceAll('@lower', '<')
                .replaceAll('@left_parent', ')')
                .replaceAll('@right_parent', '(');
        };
        String.prototype.escape = function () {
            return this
                .replaceAll('@', '@at')
                .replaceAll(']', '@left')
                .replaceAll('[', '@right')
                .replaceAll(';', '@semi')
                .replaceAll(':', '@colon')
                .replaceAll('=', '@equal')
                .replaceAll('||', '@or')
                .replaceAll('&&', '@and')
                .replaceAll('>', '@higher')
                .replaceAll('<', '@lower');
        };
    }
}
exports.Interpreter = Interpreter;
