"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.data = void 0;
const builder_1 = require("../classes/builder");
const utils_1 = require("../classes/utils");
exports.data = {
    data: new builder_1.FunctionBuilder()
        .setName('abbreviateNumber')
        .setValue('description', 'Abbreviates the provided number.')
        .setValue('use', '$abbreviateNumber[number;decimals?]')
        .setValue('returns', 'String'),
    code: async (d) => {
        await d.func?.resolve_fields(d);
        if (!d.func?.inside)
            return utils_1.Utils.Warn('Invalid inside provided in:', d.func?.name);
        let [number, decimals = 2] = d.func.fields.map(({ value }) => value);
        if (!number)
            return utils_1.Utils.Warn('Missing number in:', d.func?.name);
        if (typeof (decimals) != 'string')
            return utils_1.Utils.Warn('Invalid decimals provided:', d.func?.name);
        let tier = Math.floor(Math.log10(Math.abs(Number(number) || 1)) / 3);
        if (tier === 0) {
            return {
                code: d.code.replace(d.func?.id, number)
            };
        }
        else {
            let symbol = utils_1.symbols[tier - 1], abbreviated = Number(number) / (Math.pow(10, tier * 3)), result = abbreviated.toFixed(Number(decimals)) + symbol;
            return {
                code: d.code.replace(d.func?.id, result)
            };
        }
    }
};
