"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.data = void 0;
const tslib_1 = require("tslib");
const builder_1 = require("../classes/builder");
const utils_1 = require("../classes/utils");
const fs_1 = tslib_1.__importDefault(require("fs"));
exports.data = {
    data: new builder_1.FunctionBuilder()
        .setName('appendFile')
        .setValue('description', 'Appends content to the end of the file, if the file exists.')
        .setValue('use', '$appendFile[path;content]')
        .setValue('returns', 'Void'),
    code: async (d) => {
        await d.func?.resolve_fields(d);
        if (!d.func?.inside)
            return utils_1.Utils.Warn('Invalid inside provided in:', d.func?.name);
        let [path, content] = d.func.fields.map(({ value }) => value);
        if (!path)
            return utils_1.Utils.Warn('Path is required in:', d.func.name);
        if (!content)
            return utils_1.Utils.Warn('Content is required in:', d.func.name);
        try {
            fs_1.default.appendFileSync(path, content);
            return {
                code: d.code.replace(d.func.id, '')
            };
        }
        catch (err) {
            return utils_1.Utils.Warn('Error trying to append the provided file.', d.func.id);
        }
    }
};
