"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.data = void 0;
const builder_1 = require("../classes/builder");
const utils_1 = require("../classes/utils");
const hjson_1 = require("hjson");
exports.data = {
    data: new builder_1.FunctionBuilder()
        .setName('arrayEvery')
        .setValue('description', 'Check if all array elements meets the condition.')
        .setValue('use', '$arrayEvery[varname;comparator;query]')
        .setValue('returns', 'Boolean'),
    code: async (d) => {
        await d.func?.resolve_fields(d);
        if (!d.func?.inside)
            return utils_1.Utils.Warn('Invalid inside provided in:', d.func?.name);
        if (d.func.fields.length < 2)
            return utils_1.Utils.Warn('Invalid splits provided in:', d.func.name);
        let [id, comparator, query] = d.func.fields.map(({ value }) => value.unescape());
        let arr = (0, hjson_1.parse)(d._.vars?.[id]);
        if (!arr || !Array.isArray(arr))
            return utils_1.Utils.Warn('Invalid variable/array provided in:', d.func.name);
        if (!["==", "!=", "<=", ">=", "<", ">"].includes(comparator))
            return utils_1.Utils.Warn('Invalid comparator type provided in:', d.func.name);
        return {
            code: d.code.replace(d.func.id, arr.every(element => utils_1.Utils.condition(`${element}${comparator}${query}`))?.toString())
        };
    }
};
