"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.data = void 0;
const tslib_1 = require("tslib");
const builder_1 = require("../classes/builder");
const utils_1 = require("../classes/utils");
const lodash_1 = tslib_1.__importDefault(require("lodash"));
exports.data = {
    data: new builder_1.FunctionBuilder()
        .setName('arrayFill')
        .setValue('description', 'Replace an array element with something.')
        .setValue('use', '$arrayFill[varname;element;something?]')
        .setValue('returns', 'Void'),
    code: async (d) => {
        await d.func?.resolve_fields(d);
        if (!d.func?.inside)
            return utils_1.Utils.Warn('Invalid inside provided in:', d.func?.name);
        if (d.func.fields.length < 2)
            return utils_1.Utils.Warn('Invalid fields provided in:', d.func.name);
        let [id, element, smth] = d.func.fields.map(({ value }) => value);
        let arr = d._.vars?.[id.unescape()];
        if (!arr || !Array.isArray(arr))
            return utils_1.Utils.Warn('Invalid variable/array provided in:', d.func.name);
        let i = lodash_1.default.findIndex(arr, s => lodash_1.default.isEqual(s, utils_1.Utils.parse(element.unescape())));
        if (i >= 0) {
            if (smth)
                arr.splice(i, 1, utils_1.Utils.parse(smth.unescape()));
            else
                arr.splice(i, 1);
            d._.vars[id.unescape()] = arr;
        }
        return {
            code: d.code.replace(d.func.id, '')
        };
    }
};
