"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.data = void 0;
const builder_1 = require("../classes/builder");
const utils_1 = require("../classes/utils");
const hjson_1 = require("hjson");
exports.data = {
    data: new builder_1.FunctionBuilder()
        .setName('arrayIncludes')
        .setValue('description', 'Returns whether an array includes an element or not.')
        .setValue('use', '$arrayIncludes[varname;...querys]')
        .setValue('returns', 'String'),
    code: async (d) => {
        await d.func?.resolve_fields(d);
        if (!d.func?.inside)
            return utils_1.Utils.Warn('Invalid inside provided in:', d.func?.name);
        if (d.func.fields.length < 2)
            return utils_1.Utils.Warn('Invalid splits provided in:', d.func.name);
        let [id, ...querys] = d.func.fields.map(({ value }) => value);
        let arr = (0, hjson_1.parse)(d._.vars?.[id.unescape()]), result = false;
        if (!arr || !Array.isArray(arr))
            return utils_1.Utils.Warn('Invalid variable/array provided in:', d.func.name);
        for (const query of querys) {
            if (arr.includes(query))
                result = true;
        }
        return {
            code: d.code.replace(d.func.id, result?.toString())
        };
    }
};
