"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.data = void 0;
const builder_1 = require("../classes/builder");
const utils_1 = require("../classes/utils");
const hjson_1 = require("hjson");
exports.data = {
    data: new builder_1.FunctionBuilder()
        .setName('arrayRemove')
        .setValue('description', 'Removes a array element and, optionally, returns it.')
        .setValue('use', '$arrayRemove[varname;index;return?]')
        .setValue('returns', 'Any'),
    code: async (d) => {
        await d.func?.resolve_fields(d);
        if (!d.func?.inside)
            return utils_1.Utils.Warn('Invalid inside provided in:', d.func?.name);
        if (d.func.fields.length < 2)
            return utils_1.Utils.Warn('Invalid splits provided in:', d.func.name);
        let [id, index, returnElement = false] = d.func.fields.map(({ value }) => value);
        let arr = (0, hjson_1.parse)(d._.vars?.[id.unescape()]);
        if (!arr || !Array.isArray(arr))
            return utils_1.Utils.Warn('Invalid variable/array provided in:', d.func.name);
        if (!utils_1.Utils.isNumber(index))
            return utils_1.Utils.Warn('Invalid index provided in:', d.func.name);
        let removed = arr.splice(Number(index) - 1, 1)[0];
        return {
            code: d.code.replace(d.func.id, returnElement ? removed.toString() : '')
        };
    }
};
