"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.data = void 0;
const builder_1 = require("../classes/builder");
const utils_1 = require("../classes/utils");
const util_1 = require("util");
const hjson_1 = require("hjson");
exports.data = {
    data: new builder_1.FunctionBuilder()
        .setName('arraySlice')
        .setValue('description', 'Returns a slice from an array.')
        .setValue('use', '$arraySlice[varname;start;end?]')
        .setValue('returns', 'ArrayLike'),
    code: async (d) => {
        await d.func?.resolve_fields(d);
        if (!d.func?.inside)
            return utils_1.Utils.Warn('Invalid inside provided in:', d.func?.name);
        if (d.func.fields.length < 2)
            return utils_1.Utils.Warn('Invalid fields provided in:', d.func.name);
        let [id, start, end] = d.func.fields.map(({ value }) => value.unescape());
        let v = (0, hjson_1.parse)(d._.vars?.[id]);
        if (!v || !Array.isArray(v))
            return utils_1.Utils.Warn('Invalid variable/array provided in:', d.func.name);
        if (!utils_1.Utils.isNumber(start) || end && !utils_1.Utils.isNumber(end))
            return utils_1.Utils.Warn('Invalid index provided in:', d.func.name);
        return {
            code: d.code.replace(d.func.id, (0, util_1.inspect)(v.slice(Number(start) - 1, end ? Number(end) : undefined), { depth: 15 }).escape())
        };
    }
};
