"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.data = void 0;
const tslib_1 = require("tslib");
const builder_1 = require("../classes/builder");
const utils_1 = require("../classes/utils");
const canvas_1 = tslib_1.__importDefault(require("@napi-rs/canvas"));
exports.data = {
    data: new builder_1.FunctionBuilder()
        .setName('createCanvas')
        .setValue('description', 'Create a new canvas.')
        .setValue('use', '$createCanvas[width;height]')
        .setValue('returns', 'Void'),
    code: async (d) => {
        await d.func?.resolve_fields(d);
        if (!d.func?.inside)
            return utils_1.Utils.Warn('Invalid inside provided in:', d.func?.name);
        let [width, height] = d.func.fields.map(({ value }) => value);
        if (!(width && height))
            return utils_1.Utils.Warn('Invalid fields provided in:', d.func.name);
        if (!utils_1.Utils.isNumber(width) || !utils_1.Utils.isNumber(height))
            return utils_1.Utils.Warn('Invalid width and height provided in:', d.func.name);
        let canvas = canvas_1.default.createCanvas(Number(width), Number(height)), ctx = canvas.getContext('2d');
        d._.Canvas = { canvas, ctx };
        return {
            code: d.code.replace(d.func.id, '')
        };
    }
};
