"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.data = void 0;
const tslib_1 = require("tslib");
const builder_1 = require("../classes/builder");
const utils_1 = require("../classes/utils");
const lodash_1 = tslib_1.__importDefault(require("lodash"));
exports.data = {
    data: new builder_1.FunctionBuilder()
        .setName('deleteObjectKey')
        .setValue('description', 'Delete a property from the object.')
        .setValue('use', '$deleteObjectKey[varname;key]')
        .setValue('returns', 'Void'),
    code: async (d) => {
        await d.func?.resolve_fields(d);
        if (!d.func?.inside)
            return utils_1.Utils.Warn('Invalid inside provided in:', d.func?.name);
        let [id, key] = d.func.fields.map(({ value }) => value.unescape());
        if (!id || !key)
            return utils_1.Utils.Warn("Invalid fields in:", d.func.name);
        let obj = d._.vars?.[id];
        if (!obj)
            return utils_1.Utils.Warn('No object created found. Use $var first. Error at:', d.func.name);
        if (Array.isArray(obj) || typeof obj !== "object")
            return utils_1.Utils.Warn('Invalid object variable provided, create one using $var. Error at:', d.func.name);
        lodash_1.default.unset(obj, key);
        d._.vars[id] = obj;
        return {
            code: d.code.replace(d.func.id, '')
        };
    }
};
