"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.data = void 0;
const tslib_1 = require("tslib");
const builder_1 = require("../classes/builder");
const utils_1 = require("../classes/utils");
const fs_1 = tslib_1.__importDefault(require("fs"));
exports.data = {
    data: new builder_1.FunctionBuilder()
        .setName('fileSize')
        .setValue('description', 'Returns the file size, if the file exists.')
        .setValue('use', '$fileSize[path;decimals?]')
        .setValue('returns', 'String'),
    code: async (d) => {
        await d.func?.resolve_fields(d);
        if (!d.func?.inside)
            return utils_1.Utils.Warn('Invalid inside provided in:', d.func?.name);
        let [path, decimals = 2] = d.func.fields.map(({ value }) => value);
        if (!path)
            return utils_1.Utils.Warn('Path is required in:', d.func.name);
        if (isNaN(Number(decimals)) || Number(decimals) < 0)
            return utils_1.Utils.Warn('Invalid decimal count in:', d.func.name);
        try {
            let file = fs_1.default.statSync(path);
            let result = (file.size / 1024).toFixed(Number(decimals));
            return {
                code: d.code.replace(d.func.id, result)
            };
        }
        catch (err) {
            return utils_1.Utils.Warn('Invalid path provided in:', d.func.name);
        }
    }
};
